==> coupons-2.2.2.zip: src/QUI/ERP/Coupons/Products/PhysicalCouponProductType.php <==
<?php

namespace QUI\ERP\Coupons\Products;

use QUI;
use QUI\Locale;

/**
 * Class PhysicalCouponProductType
 *
 * Represents a physical coupon that requires shipping.
 */
class PhysicalCouponProductType extends QUI\ERP\Products\Product\Types\AbstractType
{
    /**
     * Model constructor
     *
     * @param integer $pid - Product-ID
     * @param array $product - Product Data
     *
     * @throws QUI\ERP\Products\Product\Exception
     * @throws QUI\Exception
     */
    public function __construct(int $pid, array $product = [])
    {
        parent::__construct($pid, $product);

        if (!empty($this->fields[Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW])) {
            $userDeliveryTypeSelectAllow = $this->getFieldValue(
                Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW
            );

            if ($userDeliveryTypeSelectAllow) {
                try {
                    $Field = QUI\ERP\Products\Handler\Fields::getField(
                        Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT
                    );

                    $Field->setProduct($this);

                    $this->fields[$Field->getId()] = $Field;
                } catch (QUI\Exception $Exception) {
                    QUI\System\Log::writeException($Exception);
                }
            } else {
                unset($this->fields[Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT]);
            }
        }
    }

    /**
     * @param QUI\Locale|null $Locale
     * @return string
     */
    public static function getTypeTitle(null | QUI\Locale $Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.PhysicalCouponProductType.title');
    }

    /**
     * @param Locale|null $Locale
     * @return string
     */
    public static function getTypeDescription(null | QUI\Locale $Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.PhysicalCouponProductType.description');
    }
}

==> coupons-2.2.3.zip: src/QUI/ERP/Coupons/Products/PhysicalCouponProductType.php <==
<?php

namespace QUI\ERP\Coupons\Products;

use QUI;
use QUI\Locale;

/**
 * Class PhysicalCouponProductType
 *
 * Represents a physical coupon that requires shipping.
 */
class PhysicalCouponProductType extends QUI\ERP\Products\Product\Types\AbstractType
{
    /**
     * Model constructor
     *
     * @param integer $pid - Product-ID
     * @param array<string, mixed> $product - Product Data
     *
     * @throws QUI\ERP\Products\Product\Exception
     * @throws QUI\Exception
     */
    public function __construct(int $pid, array $product = [])
    {
        parent::__construct($pid, $product);

        if (!empty($this->fields[Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW])) {
            $userDeliveryTypeSelectAllow = $this->getFieldValue(
                Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT_ALLOW
            );

            if ($userDeliveryTypeSelectAllow) {
                try {
                    $Field = QUI\ERP\Products\Handler\Fields::getField(
                        Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT
                    );

                    $Field->setProduct($this);

                    $this->fields[$Field->getId()] = $Field;
                } catch (QUI\Exception $Exception) {
                    QUI\System\Log::writeException($Exception);
                }
            } else {
                unset($this->fields[Handler::PRODUCT_FIELD_ID_USER_DELIVERY_TYPE_SELECT]);
            }
        }
    }

    /**
     * @param QUI\Locale|null $Locale
     * @return string
     */
    public static function getTypeTitle(null | QUI\Locale $Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.PhysicalCouponProductType.title');
    }

    /**
     * @param Locale|null $Locale
     * @return string
     */
    public static function getTypeDescription(null | QUI\Locale $Locale = null): string
    {
        if ($Locale === null) {
            $Locale = QUI::getLocale();
        }

        return $Locale->get('quiqqer/coupons', 'product_type.PhysicalCouponProductType.description');
    }
}
